@@ -1,27 +1,35 @@
+"""
+$description Russian live streaming platform for live video game broadcasts.
+$url goodgame.ru
+$type live
+"""
+
+import logging
 import re
 
-from streamlink.plugin import Plugin
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.plugin import Plugin, pluginmatcher
+from streamlink.stream.hls import HLSStream
+from streamlink.utils.parse import parse_json
+
+
+log = logging.getLogger(__name__)
 
 HLS_URL_FORMAT = "https://hls.goodgame.ru/hls/{0}{1}.m3u8"
 QUALITIES = {
     "1080p": "",
     "720p": "_720",
     "480p": "_480",
-    "240p": "_240"
+    "240p": "_240",
 }
 
-_url_re = re.compile(r"https?://(?:www\.)?goodgame.ru/channel/(?P<user>[^/]+)")
-_apidata_re = re.compile(r'''(?P<quote>["']?)channel(?P=quote)\s*:\s*(?P<data>{.*?})\s*,''')
+_apidata_re = re.compile(r"""(?P<quote>["']?)channel(?P=quote)\s*:\s*(?P<data>{.*?})\s*,""")
 _ddos_re = re.compile(r'document.cookie="(__DDOS_[^;]+)')
 
 
+@pluginmatcher(re.compile(
+    r"https?://(?:www\.)?goodgame\.ru/channel/(?P<user>[^/]+)",
+))
 class GoodGame(Plugin):
-    @classmethod
-    def can_handle_url(cls, url):
-        return _url_re.match(url)
-
     def _check_stream(self, url):
         res = self.session.http.get(url, acceptable_status=(200, 404))
         if res.status_code == 200:
@@ -29,30 +37,29 @@ class GoodGame(Plugin):
 
     def _get_streams(self):
         headers = {
-            "Referer": self.url
+            "Referer": self.url,
         }
         res = self.session.http.get(self.url, headers=headers)
 
         match = _ddos_re.search(res.text)
         if match:
-            self.logger.debug("Anti-DDOS bypass...")
+            log.debug("Anti-DDOS bypass...")
             headers["Cookie"] = match.group(1)
             res = self.session.http.get(self.url, headers=headers)
 
         match = _apidata_re.search(res.text)
         channel_info = match and parse_json(match.group("data"))
         if not channel_info:
-            self.logger.error("Could not find channel info")
+            log.error("Could not find channel info")
             return
 
-        self.logger.debug("Found channel info: channelkey={channelkey} pid={streamkey} online={status}",
-                          **channel_info)
-        if not channel_info['status']:
-            self.logger.debug("Channel appears to be offline")
+        log.debug("Found channel info: id={id} channelkey={channelkey} pid={streamkey} online={status}".format(**channel_info))
+        if not channel_info["status"]:
+            log.debug("Channel appears to be offline")
 
         streams = {}
         for name, url_suffix in QUALITIES.items():
-            url = HLS_URL_FORMAT.format(channel_info['streamkey'], url_suffix)
+            url = HLS_URL_FORMAT.format(channel_info["streamkey"], url_suffix)
             if not self._check_stream(url):
                 continue
 
